==> aria2-0.8.1.tar.bz2: aria2-0.8.1/src/HttpRequestCommand.cc <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#include "HttpRequestCommand.h"
#include "HttpResponseCommand.h"
#include "HttpConnection.h"
#include "prefs.h"

HttpRequestCommand::HttpRequestCommand(int cuid, Request* req,
				       DownloadEngine* e,
				       const SocketHandle& s)
  :AbstractCommand(cuid, req, e, s) {
  disableReadCheckSocket();
  setWriteCheckSocket(socket);
}

HttpRequestCommand::~HttpRequestCommand() {}

bool HttpRequestCommand::executeInternal(Segment& segment) {
  socket->setBlockingMode();
  if(req->getProtocol() == "https") {
    socket->initiateSecureConnection();
  }
  if(!e->option->getAsBool(PREF_HTTP_KEEP_ALIVE)) {
    req->setKeepAlive(false);
  }
  HttpConnection http(cuid, socket, req, e->option);
  req->segment = segment;
  http.sendRequest(segment);

  Command* command = getNextCommand();
  e->commands.push_back(command);
  return true;
}

Command* HttpRequestCommand::getNextCommand() const {
  return new HttpResponseCommand(cuid, req, e, socket);
}

==> aria2-0.11.2.tar.bz2: aria2-0.11.2/src/HttpRequestCommand.cc <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#include "HttpRequestCommand.h"
#include "HttpResponseCommand.h"
#include "HttpConnection.h"
#include "prefs.h"

HttpRequestCommand::HttpRequestCommand(int cuid,
				       const RequestHandle& req,
				       RequestGroup* requestGroup,
				       DownloadEngine* e,
				       const SocketHandle& s)
  :AbstractCommand(cuid, req, requestGroup, e, s) {
  disableReadCheckSocket();
  setWriteCheckSocket(socket);
}

HttpRequestCommand::~HttpRequestCommand() {}

bool HttpRequestCommand::executeInternal() {
  socket->setBlockingMode();
  if(req->getProtocol() == "https") {
#ifdef __MINGW32__
    // it only works in non-blocking mode
    socket->setNonBlockingMode();
#endif // __MINGW32__
    socket->initiateSecureConnection();
  }
  if(!e->option->getAsBool(PREF_HTTP_KEEP_ALIVE)) {
    req->setKeepAlive(false);
  }
  HttpRequestHandle httpRequest = new HttpRequest();
  httpRequest->setUserAgent(e->option->get(PREF_USER_AGENT));
  httpRequest->setRequest(req);
  httpRequest->setSegment(segment);
  httpRequest->setEntityLength(_requestGroup->getSegmentMan()->totalSize);
  httpRequest->configure(e->option);

  HttpConnectionHandle httpConnection = new HttpConnection(cuid, socket, e->option);

  httpConnection->sendRequest(httpRequest);

  Command* command = new HttpResponseCommand(cuid, req, _requestGroup, httpConnection, e, socket);
  e->commands.push_back(command);
  return true;
}
